# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ArtifactContent(object):
    """Represents the contents of an artifact."""

    binary = attr.ib(default=None)
    properties = attr.ib(default=None)
    rendered = attr.ib(default=None)
    text = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Invocation(object):
    """The runtime environment of the analysis tool run."""

    execution_successful = attr.ib()
    account = attr.ib(default=None)
    arguments = attr.ib(default=None)
    command_line = attr.ib(default=None)
    end_time_utc = attr.ib(default=None)
    environment_variables = attr.ib(default=None)
    executable_location = attr.ib(default=None)
    exit_code = attr.ib(default=None)
    exit_code_description = attr.ib(default=None)
    exit_signal_name = attr.ib(default=None)
    exit_signal_number = attr.ib(default=None)
    machine = attr.ib(default=None)
    notification_configuration_overrides = attr.ib(default=None)
    process_id = attr.ib(default=None)
    process_start_failure_message = attr.ib(default=None)
    properties = attr.ib(default=None)
    response_files = attr.ib(default=None)
    rule_configuration_overrides = attr.ib(default=None)
    start_time_utc = attr.ib(default=None)
    stderr = attr.ib(default=None)
    stdin = attr.ib(default=None)
    stdout = attr.ib(default=None)
    stdout_stderr = attr.ib(default=None)
    tool_configuration_notifications = attr.ib(default=None)
    tool_execution_notifications = attr.ib(default=None)
    working_directory = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ArtifactLocation(object):
    """Specifies the location of an artifact."""

    description = attr.ib(default=None)
    index = attr.ib(default=-1)
    properties = attr.ib(default=None)
    uri = attr.ib(default=None)
    uri_base_id = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Replacement(object):
    """The replacement of a single region of an artifact."""

    deleted_region = attr.ib()
    inserted_content = attr.ib(default=None)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ExternalPropertyFileReference(object):
    """Contains information that enables a SARIF consumer to locate the external property file that contains the value of an externalized property associated with the run."""

    guid = attr.ib(default=None)
    item_count = attr.ib(default=-1)
    location = attr.ib(default=None)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Region(object):
    """A region within an artifact where a result was detected."""

    byte_length = attr.ib(default=None)
    byte_offset = attr.ib(default=-1)
    char_length = attr.ib(default=None)
    char_offset = attr.ib(default=-1)
    end_column = attr.ib(default=None)
    end_line = attr.ib(default=None)
    message = attr.ib(default=None)
    properties = attr.ib(default=None)
    snippet = attr.ib(default=None)
    source_language = attr.ib(default=None)
    start_column = attr.ib(default=None)
    start_line = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class StackFrame(object):
    """A function call within a stack trace."""

    location = attr.ib(default=None)
    module = attr.ib(default=None)
    parameters = attr.ib(default=None)
    properties = attr.ib(default=None)
    thread_id = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class CodeFlow(object):
    """A set of threadFlows which together describe a pattern of code execution relevant to detecting a result."""

    thread_flows = attr.ib()
    message = attr.ib(default=None)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class GraphTraversal(object):
    """Represents a path through a graph."""

    description = attr.ib(default=None)
    edge_traversals = attr.ib(default=None)
    immutable_state = attr.ib(default=None)
    initial_state = attr.ib(default=None)
    properties = attr.ib(default=None)
    result_graph_index = attr.ib(default=-1)
    run_graph_index = attr.ib(default=-1)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Graph(object):
    """A network of nodes and directed edges that describes some aspect of the structure of the code (for example, a call graph)."""

    description = attr.ib(default=None)
    edges = attr.ib(default=None)
    nodes = attr.ib(default=None)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Conversion(object):
    """Describes how a converter transformed the output of a static analysis tool from the analysis tool's native output format into the SARIF format."""

    tool = attr.ib()
    analysis_tool_log_files = attr.ib(default=None)
    invocation = attr.ib(default=None)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Notification(object):
    """Describes a condition relevant to the tool itself, as opposed to being relevant to a target being analyzed by the tool."""

    message = attr.ib()
    associated_rule = attr.ib(default=None)
    descriptor = attr.ib(default=None)
    exception = attr.ib(default=None)
    level = attr.ib(default="warning")
    locations = attr.ib(default=None)
    properties = attr.ib(default=None)
    thread_id = attr.ib(default=None)
    time_utc = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Run(object):
    """Describes a single run of an analysis tool, and contains the reported output of that run."""

    tool = attr.ib()
    addresses = attr.ib(default=None)
    artifacts = attr.ib(default=None)
    automation_details = attr.ib(default=None)
    baseline_guid = attr.ib(default=None)
    column_kind = attr.ib(default=None)
    conversion = attr.ib(default=None)
    default_encoding = attr.ib(default=None)
    default_source_language = attr.ib(default=None)
    external_property_file_references = attr.ib(default=None)
    graphs = attr.ib(default=None)
    invocations = attr.ib(default=None)
    language = attr.ib(default="en-US")
    logical_locations = attr.ib(default=None)
    newline_sequences = attr.ib(default=['\r\n', '\n'])
    original_uri_base_ids = attr.ib(default=None)
    policies = attr.ib(default=None)
    properties = attr.ib(default=None)
    redaction_tokens = attr.ib(default=None)
    results = attr.ib(default=None)
    run_aggregates = attr.ib(default=None)
    special_locations = attr.ib(default=None)
    taxonomies = attr.ib(default=None)
    thread_flow_locations = attr.ib(default=None)
    translations = attr.ib(default=None)
    version_control_provenance = attr.ib(default=None)
    web_requests = attr.ib(default=None)
    web_responses = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class VersionControlDetails(object):
    """Specifies the information necessary to retrieve a desired revision from a version control system."""

    repository_uri = attr.ib()
    as_of_time_utc = attr.ib(default=None)
    branch = attr.ib(default=None)
    mapped_to = attr.ib(default=None)
    properties = attr.ib(default=None)
    revision_id = attr.ib(default=None)
    revision_tag = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Suppression(object):
    """A suppression that is relevant to a result."""

    kind = attr.ib()
    guid = attr.ib(default=None)
    justification = attr.ib(default=None)
    location = attr.ib(default=None)
    properties = attr.ib(default=None)
    state = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Artifact(object):
    """A single artifact. In some cases, this artifact might be nested within another artifact."""

    contents = attr.ib(default=None)
    description = attr.ib(default=None)
    encoding = attr.ib(default=None)
    hashes = attr.ib(default=None)
    last_modified_time_utc = attr.ib(default=None)
    length = attr.ib(default=-1)
    location = attr.ib(default=None)
    mime_type = attr.ib(default=None)
    offset = attr.ib(default=None)
    parent_index = attr.ib(default=-1)
    properties = attr.ib(default=None)
    roles = attr.ib(default=None)
    source_language = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class LocationRelationship(object):
    """Information about the relation of one location to another."""

    target = attr.ib()
    description = attr.ib(default=None)
    kinds = attr.ib(default=['relevant'])
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ExternalPropertyFileReferences(object):
    """References to external property files that should be inlined with the content of a root log file."""

    addresses = attr.ib(default=None)
    artifacts = attr.ib(default=None)
    conversion = attr.ib(default=None)
    driver = attr.ib(default=None)
    extensions = attr.ib(default=None)
    externalized_properties = attr.ib(default=None)
    graphs = attr.ib(default=None)
    invocations = attr.ib(default=None)
    logical_locations = attr.ib(default=None)
    policies = attr.ib(default=None)
    properties = attr.ib(default=None)
    results = attr.ib(default=None)
    taxonomies = attr.ib(default=None)
    thread_flow_locations = attr.ib(default=None)
    translations = attr.ib(default=None)
    web_requests = attr.ib(default=None)
    web_responses = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class MultiformatMessageString(object):
    """A message string or message format string rendered in multiple formats."""

    text = attr.ib()
    markdown = attr.ib(default=None)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class TranslationMetadata(object):
    """Provides additional metadata related to translation."""

    name = attr.ib()
    download_uri = attr.ib(default=None)
    full_description = attr.ib(default=None)
    full_name = attr.ib(default=None)
    information_uri = attr.ib(default=None)
    properties = attr.ib(default=None)
    short_description = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ResultProvenance(object):
    """Contains information about how and when a result was detected."""

    conversion_sources = attr.ib(default=None)
    first_detection_run_guid = attr.ib(default=None)
    first_detection_time_utc = attr.ib(default=None)
    invocation_index = attr.ib(default=-1)
    last_detection_run_guid = attr.ib(default=None)
    last_detection_time_utc = attr.ib(default=None)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class WebRequest(object):
    """Describes an HTTP request."""

    body = attr.ib(default=None)
    headers = attr.ib(default=None)
    index = attr.ib(default=-1)
    method = attr.ib(default=None)
    parameters = attr.ib(default=None)
    properties = attr.ib(default=None)
    protocol = attr.ib(default=None)
    target = attr.ib(default=None)
    version = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Attachment(object):
    """An artifact relevant to a result."""

    artifact_location = attr.ib()
    description = attr.ib(default=None)
    properties = attr.ib(default=None)
    rectangles = attr.ib(default=None)
    regions = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Address(object):
    """A physical or virtual address, or a range of addresses, in an 'addressable region' (memory or a binary file)."""

    absolute_address = attr.ib(default=-1)
    fully_qualified_name = attr.ib(default=None)
    index = attr.ib(default=-1)
    kind = attr.ib(default=None)
    length = attr.ib(default=None)
    name = attr.ib(default=None)
    offset_from_parent = attr.ib(default=None)
    parent_index = attr.ib(default=-1)
    properties = attr.ib(default=None)
    relative_address = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Rectangle(object):
    """An area within an image."""

    bottom = attr.ib(default=None)
    left = attr.ib(default=None)
    message = attr.ib(default=None)
    properties = attr.ib(default=None)
    right = attr.ib(default=None)
    top = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Node(object):
    """Represents a node in a graph."""

    id = attr.ib()
    children = attr.ib(default=None)
    label = attr.ib(default=None)
    location = attr.ib(default=None)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ToolComponent(object):
    """A component, such as a plug-in or the driver, of the analysis tool that was run."""

    name = attr.ib()
    associated_component = attr.ib(default=None)
    contents = attr.ib(default=['localizedData', 'nonLocalizedData'])
    dotted_quad_file_version = attr.ib(default=None)
    download_uri = attr.ib(default=None)
    full_description = attr.ib(default=None)
    full_name = attr.ib(default=None)
    global_message_strings = attr.ib(default=None)
    guid = attr.ib(default=None)
    information_uri = attr.ib(default=None)
    is_comprehensive = attr.ib(default=None)
    language = attr.ib(default="en-US")
    localized_data_semantic_version = attr.ib(default=None)
    locations = attr.ib(default=None)
    minimum_required_localized_data_semantic_version = attr.ib(default=None)
    notifications = attr.ib(default=None)
    organization = attr.ib(default=None)
    product = attr.ib(default=None)
    product_suite = attr.ib(default=None)
    properties = attr.ib(default=None)
    release_date_utc = attr.ib(default=None)
    rules = attr.ib(default=None)
    semantic_version = attr.ib(default=None)
    short_description = attr.ib(default=None)
    supported_taxonomies = attr.ib(default=None)
    taxa = attr.ib(default=None)
    translation_metadata = attr.ib(default=None)
    version = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Location(object):
    """A location within a programming artifact."""

    annotations = attr.ib(default=None)
    id = attr.ib(default=-1)
    logical_locations = attr.ib(default=None)
    message = attr.ib(default=None)
    physical_location = attr.ib(default=None)
    properties = attr.ib(default=None)
    relationships = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class SarifLog(object):
    """Static Analysis Results Format (SARIF) Version 2.1.0-rtm.4 JSON Schema: a standard format for the output of static analysis tools."""

    runs = attr.ib()
    version = attr.ib()
    schema_uri = attr.ib(default=None)
    inline_external_properties = attr.ib(default=None)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Result(object):
    """A result produced by an analysis tool."""

    message = attr.ib()
    analysis_target = attr.ib(default=None)
    attachments = attr.ib(default=None)
    baseline_state = attr.ib(default=None)
    code_flows = attr.ib(default=None)
    correlation_guid = attr.ib(default=None)
    fingerprints = attr.ib(default=None)
    fixes = attr.ib(default=None)
    graph_traversals = attr.ib(default=None)
    graphs = attr.ib(default=None)
    guid = attr.ib(default=None)
    hosted_viewer_uri = attr.ib(default=None)
    kind = attr.ib(default="fail")
    level = attr.ib(default="warning")
    locations = attr.ib(default=None)
    occurrence_count = attr.ib(default=None)
    partial_fingerprints = attr.ib(default=None)
    properties = attr.ib(default=None)
    provenance = attr.ib(default=None)
    rank = attr.ib(default=-1.0)
    related_locations = attr.ib(default=None)
    rule = attr.ib(default=None)
    rule_id = attr.ib(default=None)
    rule_index = attr.ib(default=-1)
    stacks = attr.ib(default=None)
    suppressions = attr.ib(default=None)
    taxa = attr.ib(default=None)
    web_request = attr.ib(default=None)
    web_response = attr.ib(default=None)
    work_item_uris = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ReportingDescriptorReference(object):
    """Information about how to locate a relevant reporting descriptor."""

    guid = attr.ib(default=None)
    id = attr.ib(default=None)
    index = attr.ib(default=-1)
    properties = attr.ib(default=None)
    tool_component = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class LogicalLocation(object):
    """A logical location of a construct that produced a result."""

    decorated_name = attr.ib(default=None)
    fully_qualified_name = attr.ib(default=None)
    index = attr.ib(default=-1)
    kind = attr.ib(default=None)
    name = attr.ib(default=None)
    parent_index = attr.ib(default=-1)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ThreadFlowLocation(object):
    """A location visited by an analysis tool while simulating or monitoring the execution of a program."""

    execution_order = attr.ib(default=-1)
    execution_time_utc = attr.ib(default=None)
    importance = attr.ib(default="important")
    index = attr.ib(default=-1)
    kinds = attr.ib(default=None)
    location = attr.ib(default=None)
    module = attr.ib(default=None)
    nesting_level = attr.ib(default=None)
    properties = attr.ib(default=None)
    stack = attr.ib(default=None)
    state = attr.ib(default=None)
    taxa = attr.ib(default=None)
    web_request = attr.ib(default=None)
    web_response = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ExternalProperties(object):
    """The top-level element of an external property file."""

    addresses = attr.ib(default=None)
    artifacts = attr.ib(default=None)
    conversion = attr.ib(default=None)
    driver = attr.ib(default=None)
    extensions = attr.ib(default=None)
    externalized_properties = attr.ib(default=None)
    graphs = attr.ib(default=None)
    guid = attr.ib(default=None)
    invocations = attr.ib(default=None)
    logical_locations = attr.ib(default=None)
    policies = attr.ib(default=None)
    properties = attr.ib(default=None)
    results = attr.ib(default=None)
    run_guid = attr.ib(default=None)
    schema = attr.ib(default=None)
    taxonomies = attr.ib(default=None)
    thread_flow_locations = attr.ib(default=None)
    translations = attr.ib(default=None)
    version = attr.ib(default=None)
    web_requests = attr.ib(default=None)
    web_responses = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ReportingConfiguration(object):
    """Information about a rule or notification that can be configured at runtime."""

    enabled = attr.ib(default=True)
    level = attr.ib(default="warning")
    parameters = attr.ib(default=None)
    properties = attr.ib(default=None)
    rank = attr.ib(default=-1.0)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ThreadFlow(object):
    """Describes a sequence of code locations that specify a path through a single thread of execution such as an operating system or fiber."""

    locations = attr.ib()
    id = attr.ib(default=None)
    immutable_state = attr.ib(default=None)
    initial_state = attr.ib(default=None)
    message = attr.ib(default=None)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Message(object):
    """Encapsulates a message intended to be read by the end user."""

    arguments = attr.ib(default=None)
    id = attr.ib(default=None)
    markdown = attr.ib(default=None)
    properties = attr.ib(default=None)
    text = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Tool(object):
    """The analysis tool that was run."""

    driver = attr.ib()
    extensions = attr.ib(default=None)
    properties = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class WebResponse(object):
    """Describes the response to an HTTP request."""

    body = attr.ib(default=None)
    headers = attr.ib(default=None)
    index = attr.ib(default=-1)
    no_response_received = attr.ib(default=None)
    properties = attr.ib(default=None)
    protocol = attr.ib(default=None)
    reason_phrase = attr.ib(default=None)
    status_code = attr.ib(default=None)
    version = attr.ib(default=None)



# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ReportingDescriptor(object):
    """Metadata that describes a specific report produced by the tool, as part of the analysis it provides or its runtime reporting."""

    id = attr.ib()
    default_configuration = attr.ib(default=None)
    deprecated_guids = attr.ib(default=None)
    deprecated_ids = attr.ib(default=None)
    deprecated_names = attr.ib(default=None)
    full_description = attr.ib(default=None)
    guid = attr.ib(default=None)
    help = attr.ib(default=None)
    help_uri = attr.ib(default=None)
    message_strings = attr.ib(default=None)
    name = attr.ib(default=None)
    properties = attr.ib(default=None)
    relationships = attr.ib(default=None)
    short_description = attr.ib(default=None)
